#ifndef __PDFFORMFUNC_H__
#define __PDFFORMFUNC_H__

#include <windows.h>

#ifdef __cplusplus
extern "C" {
#endif

#define EXTERN __declspec(dllexport)

//PDFForm_SetLicenseKey
//Parameters:
//  lpLicenseKey: a License Key which issued by VeryPDF
EXTERN void WINAPI PDFForm_SetLicenseKey(LPCTSTR lpLicenseKey);


//PDFForm_MergeFDFIntoPDF
//  Merge FDF file into an existing PDF file and generate a new filled PDF file.
//Parameters:
//  lpInPDF: input PDF file
//  lpInFDF: input FDF file
//  lpOutPDF: merged PDF file
//Return value:
//  TRUE is success, FALSE is fail
EXTERN BOOL WINAPI PDFForm_MergeFDFIntoPDF(LPCTSTR lpInPDF, LPCTSTR lpInFDF, LPCTSTR lpOutPDF);


//PDFForm_ExtractFDFFromPDF
//  Extract FDF file from a filled PDF file.
//Parameters:
//  lpInPDF: input PDF file
//  lpOutFDF: output FDF file
//Return value:
//  TRUE is success, FALSE is fail
EXTERN BOOL WINAPI PDFForm_ExtractFDFFromPDF(LPCTSTR lpInPDF, LPCTSTR lpOutFDF);


//PDFForm_FlattenPDF
//  Flatten a form filled PDF file
//Parameters:
//  lpInPDF: input PDF file
//  lpOutPDF: output PDF file
//Return value:
//  TRUE is success, FALSE is fail
EXTERN BOOL WINAPI PDFForm_FlattenPDF(LPCTSTR lpInPDF, LPCTSTR lpOutPDF);


//PDFForm_EncryptPDF
//  Encrypt a PDF file.
//Parameters:
//  lpInPDF: input PDF file
//  lpUserPwd: user password
//  lpOwnerPwd: owner password
//  lpPermissions: permissions, it can be following values,
//					Printing // top quality printing
//					ModifyContents = ModifyContents | Assembly
//					Copy = Copy | ScreenReaders
//					ModifyAnnotations = ModifyAnnotations | FillIn
//					FillIn
//					ScreenReaders
//					Assembly
//					DegradedPrinting
//  nKeyLen: 128 or 40 bits
//  lpOutPDF: output PDF file
//Return value:
//  TRUE is success, FALSE is fail
EXTERN BOOL WINAPI PDFForm_EncryptPDF(LPCTSTR lpInPDF, LPCTSTR lpUserPwd, LPCTSTR lpOwnerPwd, LPCTSTR lpPermissions,
					   int nKeyLen, LPCTSTR lpOutPDF);


//PDFForm_Alloc
//Return value:
// 0 is an error, other values are valid ID.
EXTERN long WINAPI PDFForm_Alloc();


//PDFForm_Free
//Parameters:
//  id: a valid ID returned by PDFForm_Alloc() function
//
//Return value:
//  0 is success, other values are indicate an error
EXTERN long WINAPI PDFForm_Free(long id);


//PDFForm_SetTextField
//Parameters:
//  id: a valid ID returned by PDFForm_Alloc() function
//  lpFieldName: form field name
//  lpFieldValue: form field value
//
//Return value:
//  if return value less than zero, it is indicate an error, 
//  if return value large than zero, it is the number of form fields in the list
EXTERN long WINAPI PDFForm_SetTextField(long id, LPCTSTR lpFieldName, LPCTSTR lpFieldValue);


//PDFForm_SetCheckBox
//Parameters:
//  id: a valid ID returned by PDFForm_Alloc() function
//  lpFieldName: form field name
//  lpFieldValue: form field value
//
//Return value:
//  if return value less than zero, it is indicate an error, 
//  if return value large than zero, it is the number of form fields in the list
EXTERN long WINAPI PDFForm_SetCheckBox(long id, LPCTSTR lpFieldName, LPCTSTR lpFieldValue);


//PDFForm_Apply
//Parameters:
//  id: a valid ID returned by PDFForm_Alloc() function
//  lpInFile: input PDF file
//  lpOutFile: output PDF file
//  bFlatten: make the output file flatten or not 
//
//Return value:
//  0 is success, other values are indicate an error
//  -6: create FDF file error
//  -7: import form data into PDF file error
//  -8: flatten filled PDF file error
EXTERN long WINAPI PDFForm_Apply(long id, LPCTSTR lpInFile, LPCTSTR lpOutFile, LONG bFlatten);


//PDFForm_ClearFields
//Parameters:
//  id: a valid ID returned by PDFForm_Alloc() function
//
//Return value:
//  0 is success, other values are indicate an error
EXTERN long WINAPI PDFForm_ClearFields(long id);

#ifdef __cplusplus
}
#endif

#endif